@@ -65,7 +65,6 @@ static gchar *tv_input;
 static gint tv_width;
 static gint tv_height;
 static gint tv_fps;
-static gint pref_volume;
 
 typedef struct _PlayData {
     gchar uri[4096];
@@ -172,6 +171,7 @@ static GOptionEntry entries[] = {
      NULL},
     {"dvd_device", 0, 0, G_OPTION_ARG_STRING, &option_dvd_device, N_("DVD Device Name"), "Path to device or folder"},
     {"vo", 0, 0, G_OPTION_ARG_STRING, &option_vo, N_("Video Output Device Name"), "mplayer vo name"},
+    {"mplayer", 0, 0, G_OPTION_ARG_STRING, &mplayer_bin, N_("Use specified mplayer"), "Path to mplayer binary"},
     {NULL}
 };
 
@@ -615,22 +615,31 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
 #ifdef LIBGDA_ENABLED
         metadata = get_db_metadata(db_connection, uri);
 
-        if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL) == 1 && metadata->resumable) {
+        if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL) == 1 && metadata->resumable
+            && (int) (metadata->position) > 0) {
             position_text = seconds_to_string(metadata->position);
-            GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window),
-                                                       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                       GTK_MESSAGE_QUESTION,
-                                                       GTK_BUTTONS_YES_NO,
-                                                       _("Resume Playback of %s at %s"),
-                                                       metadata->title, position_text);
-            if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
+            if (resume_mode == RESUME_ALWAYS_ASK) {
+                GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(window),
+                                                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                           GTK_MESSAGE_QUESTION,
+                                                           GTK_BUTTONS_YES_NO,
+                                                           _("Resume Playback of %s at %s"),
+                                                           metadata->title, position_text);
+                if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES) {
+                    gmtk_media_tracker_set_length(tracker, metadata->length_value);
+                    gmtk_media_tracker_set_position(tracker, metadata->position);
+                    gmtk_media_player_set_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_START_TIME,
+                                                           metadata->position);
+                }
+                gtk_widget_destroy(dialog);
+                g_free(position_text);
+            }
+            if (resume_mode == RESUME_BUT_NEVER_ASK) {
                 gmtk_media_tracker_set_length(tracker, metadata->length_value);
                 gmtk_media_tracker_set_position(tracker, metadata->position);
                 gmtk_media_player_set_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_START_TIME,
                                                        metadata->position);
             }
-            gtk_widget_destroy(dialog);
-            g_free(position_text);
         }
         free_metadata(metadata);
 #endif
@@ -836,6 +845,7 @@ int main(int argc, char *argv[])
     use_mplayer2 = FALSE;
     enable_global_menu = FALSE;
     cover_art_uri = NULL;
+    resume_mode = RESUME_ALWAYS_ASK;
 
 
     // All Gtk docs say we need to call g_thread_init() and gdk_threads_init() before gtk_init()
@@ -900,6 +910,9 @@ int main(int argc, char *argv[])
     pplevel = gm_pref_store_get_int(gm_store, PPLEVEL);
 #ifndef HAVE_ASOUNDLIB
     volume = gm_pref_store_get_int(gm_store, VOLUME);
+    if (pref_volume == -1) {
+        pref_volume = volume;
+    }
 #endif
     audio_channels = gm_pref_store_get_int(gm_store, AUDIO_CHANNELS);
     use_hw_audio = gm_pref_store_get_boolean(gm_store, USE_HW_AUDIO);
@@ -948,6 +961,8 @@ int main(int argc, char *argv[])
     subtitle_fuzziness = gm_pref_store_get_int(gm_store, SUBTITLE_FUZZINESS);
     showsubtitles = gm_pref_store_get_boolean_with_default(gm_store, SHOW_SUBTITLES, TRUE);
 
+    resume_mode = gm_pref_store_get_int(gm_store, RESUME_MODE);
+
     qt_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_QT);
     real_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_REAL);
     wmp_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_WMP);
@@ -978,7 +993,8 @@ int main(int argc, char *argv[])
     }
 
     enable_nautilus_plugin = gm_pref_store_get_boolean_with_default(gm_store, ENABLE_NAUTILUS_PLUGIN, TRUE);
-    mplayer_bin = gm_pref_store_get_string(gm_store, MPLAYER_BIN);
+    if (mplayer_bin == NULL)
+        mplayer_bin = gm_pref_store_get_string(gm_store, MPLAYER_BIN);
     if (mplayer_bin != NULL && !g_file_test(mplayer_bin, G_FILE_TEST_EXISTS)) {
         g_free(mplayer_bin);
         mplayer_bin = NULL;
@@ -1084,6 +1100,7 @@ int main(int argc, char *argv[])
         if (remember_softvol && volume_softvol != -1) {
             gm_log(verbose, G_LOG_LEVEL_INFO, "Using last volume of %f%%", volume_softvol * 100.0);
             volume = (gdouble) volume_softvol *100.0;
+            audio_device.volume = volume / 100.0;
         } else {
             volume = 100.0;
         }
@@ -1308,16 +1325,18 @@ int main(int argc, char *argv[])
     // disabling this line seems to help with hangs on startup when using pulseaudio
     //gm_audio_get_volume(&audio_device);
     set_media_player_attributes(media);
-    if (!softvol) {
+    if (softvol) {
         if (pref_volume != -1) {
             audio_device.volume = (gdouble) pref_volume / 100.0;
             gm_log(verbose, G_LOG_LEVEL_INFO, "The volume on '%s' is %f", audio_device.description,
                    audio_device.volume);
             volume = audio_device.volume * 100;
+        } else {
+            audio_device.volume = volume / 100.0;
         }
-    } else {
-        audio_device.volume = volume / 100.0;
     }
+    gm_log(verbose, G_LOG_LEVEL_DEBUG, "Volume is %lf Audio Device Volume = %f", volume, audio_device.volume);
+
 #ifdef GTK2_12_ENABLED
     gtk_scale_button_set_value(GTK_SCALE_BUTTON(vol_slider), audio_device.volume);
 #else
@@ -1376,6 +1395,8 @@ int main(int argc, char *argv[])
     // put the request to update the volume into the list of tasks to complete
     g_idle_add(hookup_volume, NULL);
     g_idle_add(set_volume, NULL);
+    if (fullscreen && embed_window == 0)
+        g_idle_add(set_fullscreen, NULL);
     gtk_main();
     return 0;
 }
