@@ -825,7 +825,7 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
 
     if (remember_loc)
         use_remember_loc = TRUE;
-    adjust_layout();
+    g_idle_add(set_adjust_layout, idledata);
 }
 
 void undo_playlist_sort(GtkWidget * widget, void *data)
@@ -864,11 +864,22 @@ void create_playlist_widget()
     gchar **split;
     gchar *joined;
 
+#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION >= 2
+    plvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 12);
+    gtk_box_set_homogeneous(GTK_BOX(plvbox), FALSE);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_box_set_homogeneous(GTK_BOX(hbox), FALSE);
+    ctrlbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_box_set_homogeneous(GTK_BOX(ctrlbox), FALSE);
+    closebox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_box_set_homogeneous(GTK_BOX(closebox), FALSE);
+#else
     plvbox = gtk_vbox_new(FALSE, 12);
     hbox = gtk_hbox_new(FALSE, 12);
     gtk_box_set_homogeneous(GTK_BOX(hbox), FALSE);
     ctrlbox = gtk_hbox_new(FALSE, 0);
     closebox = gtk_hbox_new(FALSE, 0);
+#endif
 
     list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(playliststore));
     gtk_tree_view_set_enable_search(GTK_TREE_VIEW(list), FALSE);
@@ -915,6 +926,7 @@ void create_playlist_widget()
 
     count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL);
     renderer = gtk_cell_renderer_text_new();
+    g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, "ellipsize-set", TRUE, NULL);
     column =
         gtk_tree_view_column_new_with_attributes(ngettext
                                                  ("Item to play", "Items to Play", count),
@@ -938,6 +950,7 @@ void create_playlist_widget()
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
     renderer = gtk_cell_renderer_text_new();
+    g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, "ellipsize-set", TRUE, NULL);
     column = gtk_tree_view_column_new_with_attributes(_("Artist"), renderer, "text", ARTIST_COLUMN, NULL);
     gtk_tree_view_column_set_expand(column, TRUE);
     //gtk_tree_view_column_set_max_width(column, 20);
@@ -949,6 +962,7 @@ void create_playlist_widget()
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
     renderer = gtk_cell_renderer_text_new();
+    g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, "ellipsize-set", TRUE, NULL);
     column = gtk_tree_view_column_new_with_attributes(_("Album"), renderer, "text", ALBUM_COLUMN, NULL);
     gtk_tree_view_column_set_expand(column, TRUE);
     //gtk_tree_view_column_set_max_width(column, 20);
